# Loducode utils

Basic components for the development of loducode s.a.s.

## functionalities

- **Admin**
    - ReadOnlyAdmin
    - ReadOnlyStackedInline
    - ReadOnlyTabularInline
- **Models**
    - Audit
    - City  
- **Tasks**
    - send_mail_task(email, subject, message)
- **Urls Api**
    - /api/token/
    - /api/logout/
    - /api/forget/
- **Utils**
    - PaginatedListView
- **Views api**
    - ObtainCustomAuthToken
    - LogoutView
    - ForgetPasswordView

### Required ENV

- ID_PHONE
- PRODUCT_ID
- TOKEN